@@ -215,6 +215,7 @@ listVolumeSchedules = [
 ]
 
 deleteObject = True
+editObject = True
 allowAccessFromHostList = True
 removeAccessFromHostList = True
 failoverToReplicant = True
@@ -234,8 +235,8 @@ getVolumeCountLimits = {
     'provisionedCount': 100
 }
 
-refreshDependentDuplicate = {
-    'dependentDuplicate': 1
+refreshDuplicate = {
+     'dependentDuplicate': 1
 }
 
 convertCloneDependentToIndependent = {
