@@ -11,7 +11,6 @@ from re import match
 
 from SoftLayer import exceptions
 
-
 CATEGORY_MASK = '''id, isRequired, itemCategory[id, name, categoryCode]'''
 
 ITEM_MASK = '''id, keyName, description, itemCategory, categories, prices'''
@@ -61,6 +60,28 @@ class OrderingManager(object):
         packages = self.filter_outlet_packages(packages)
         return packages
 
+    def get_order_detail(self, order_id, mask=None):
+        """Get order details.
+
+        :param int order_id: to specify the order that we want to retrieve.
+        :param string mask: Mask to specify the properties we want to retrieve.
+        """
+        _default_mask = (
+            'mask[orderTotalAmount,orderApprovalDate,'
+            'initialInvoice[id,amount,invoiceTotalAmount,'
+            'invoiceTopLevelItems[id, description, hostName, domainName, oneTimeAfterTaxAmount,'
+            'recurringAfterTaxAmount, createDate,'
+            'categoryCode,'
+            'category[name],'
+            'location[name],'
+            'children[id, category[name], description, oneTimeAfterTaxAmount,recurringAfterTaxAmount]]],'
+            'items[description],userRecord[displayName,userStatus]]')
+
+        mask = _default_mask if mask is None else mask
+
+        order = self.billing_svc.getObject(mask=mask, id=order_id)
+        return order
+
     @staticmethod
     def filter_outlet_packages(packages):
         """Remove packages designated as OUTLET.
@@ -634,6 +655,9 @@ class OrderingManager(object):
 
         if isinstance(location, int):
             return location
+        # Some orders dont require a location, just use 0
+        if location.upper() == "NONE":
+            return 0
         mask = "mask[id,name,regions[keyname]]"
         if match(r'[a-zA-Z]{3}[0-9]{2}', location) is not None:
             search = {'name': {'operation': location}}
@@ -643,3 +667,41 @@ class OrderingManager(object):
         if len(datacenter) != 1:
             raise exceptions.SoftLayerError("Unable to find location: %s" % location)
         return datacenter[0]['id']
+
+    def get_item_prices_by_location(self, location, package_keyname):
+        """Returns the item prices by location.
+
+        :param string package_keyname: The package for which to get the items.
+        :param string location: location name or keyname to get the item prices.
+        """
+        object_mask = "filteredMask[pricingLocationGroup[locations]]"
+        location_name = self.resolve_location_name(location)
+        object_filter = {
+            "itemPrices": {"pricingLocationGroup": {"locations": {"name": {"operation": location_name}}}}}
+        package = self.get_package_by_key(package_keyname)
+
+        return self.client.call('SoftLayer_Product_Package', 'getItemPrices', mask=object_mask, filter=object_filter,
+                                id=package['id'])
+
+    def resolve_location_name(self, location_key):
+        """Resolves a location name using a string location key.
+
+        :param string location_key: A string location used to resolve the location name.
+        :return: An location name.
+        """
+
+        default_region_keyname = 'unknown'
+        if not location_key or location_key == default_region_keyname:
+            raise exceptions.SoftLayerError("Invalid location {}".format(location_key))
+
+        default_regions = [{'keyname': default_region_keyname}]
+        index_first = 0
+        object_mask = "mask[regions]"
+        locations = self.client.call('SoftLayer_Location', 'getDatacenters', mask=object_mask)
+        for location in locations:
+            location_name = location.get('name')
+            if location_name == location_key:
+                return location_key
+            if location.get('regions', default_regions)[index_first].get('keyname') == location_key:
+                return location_name
+        raise exceptions.SoftLayerError("Location {} does not exist".format(location_key))
