@@ -360,8 +360,23 @@ class ServerCLITests(testing.TestCase):
 
         self.assert_no_fail(result)
         output = json.loads(result.output)
-        self.assertEqual(output[0][0]['Value'], 'wdc01')
-        self.assert_called_with('SoftLayer_Product_Package', 'getAllObjects')
+        self.assertEqual(output[0][0]['Value'], 'wdc07')
+
+    def test_create_options_prices(self):
+        result = self.run_command(['server', 'create-options', '--prices'])
+
+        self.assert_no_fail(result)
+        output = json.loads(result.output)
+        self.assertEqual(output[2][0]['Monthly'], str(0.1))
+        self.assertEqual(output[2][0]['Key'], 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT')
+
+    def test_create_options_location(self):
+        result = self.run_command(['server', 'create-options', '--prices', 'dal13'])
+
+        self.assert_no_fail(result)
+        output = json.loads(result.output)
+        self.assertEqual(output[2][0]['Monthly'], str(0.1))
+        self.assertEqual(output[2][0]['Key'], 'OS_UBUNTU_14_04_LTS_TRUSTY_TAHR_64_BIT')
 
     @mock.patch('SoftLayer.HardwareManager.place_order')
     def test_create_server(self, order_mock):
