@@ -594,6 +594,10 @@ class OrderingTests(testing.TestCase):
         dc_id = self.ordering.get_location_id(1234)
         self.assertEqual(1234, dc_id)
 
+    def test_get_location_id_NONE(self):
+        dc_id = self.ordering.get_location_id("NONE")
+        self.assertEqual(0, dc_id)
+
     def test_location_group_id_none(self):
         # RestTransport uses None for empty locationGroupId
         category1 = {'categoryCode': 'cat1'}
@@ -731,7 +735,7 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "GUEST_CORE_1_DEDICATED",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['GUEST_CORE_1_DEDICATED', 'OS_RHEL_7_X_LAMP_64_BIT'])
 
@@ -748,7 +752,7 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "READHEAVY_TIER",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['READHEAVY_TIER', 'STORAGE_SPACE_FOR_2_IOPS_PER_GB'])
 
@@ -766,8 +770,74 @@ class OrderingTests(testing.TestCase):
                 "capacity": "1",
                 "id": 10201,
                 "keyName": "GUEST_CORE_1_DEDICATED",
-        }]
+            }]
 
         item_capacity = self.ordering.get_item_capacity(items, ['INTEL_XEON_2690_2_60', 'BANDWIDTH_20000_GB'])
 
         self.assertEqual(24, int(item_capacity))
+
+    def test_get_oder_detail_mask(self):
+        order_id = 12345
+        test_mask = 'mask[id]'
+        self.ordering.get_order_detail(order_id, mask=test_mask)
+        self.assert_called_with('SoftLayer_Billing_Order', 'getObject', identifier=order_id, mask=test_mask)
+
+    def test_get_oder_detail_default_mask(self):
+        order_id = 12345
+        _default_mask = (
+            'mask[orderTotalAmount,orderApprovalDate,'
+            'initialInvoice[id,amount,invoiceTotalAmount,'
+            'invoiceTopLevelItems[id, description, hostName, domainName, oneTimeAfterTaxAmount,'
+            'recurringAfterTaxAmount, createDate,'
+            'categoryCode,'
+            'category[name],'
+            'location[name],'
+            'children[id, category[name], description, oneTimeAfterTaxAmount,recurringAfterTaxAmount]]],'
+            'items[description],userRecord[displayName,userStatus]]')
+        self.ordering.get_order_detail(order_id)
+        self.assert_called_with('SoftLayer_Billing_Order', 'getObject', identifier=order_id, mask=_default_mask)
+
+    def test_get_item_prices_by_location_name(self):
+        object_mask = "filteredMask[pricingLocationGroup[locations]]"
+        object_filter = {
+            "itemPrices": {"pricingLocationGroup": {"locations": {"name": {"operation": 'dal13'}}}}}
+        self.ordering.get_item_prices_by_location('dal13', 'TEST')
+
+        self.assert_called_with('SoftLayer_Product_Package', 'getItemPrices', mask=object_mask, filter=object_filter)
+
+    def test_get_item_prices_by_location_keyname(self):
+        object_mask = "filteredMask[pricingLocationGroup[locations]]"
+        object_filter = {
+            "itemPrices": {"pricingLocationGroup": {"locations": {"name": {"operation": 'dal13'}}}}}
+        self.ordering.get_item_prices_by_location('DALLAS13', 'TEST')
+
+        self.assert_called_with('SoftLayer_Product_Package', 'getItemPrices', mask=object_mask, filter=object_filter)
+
+    def test_resolve_location_name(self):
+        location_name_expected = 'dal13'
+        object_mask = "mask[regions]"
+        location_name = self.ordering.resolve_location_name('DALLAS13')
+        self.assertEqual(location_name, location_name_expected)
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters', mask=object_mask)
+
+    def test_resolve_location_name_by_keyname(self):
+        location_name_expected = 'dal13'
+        object_mask = "mask[regions]"
+        location_name = self.ordering.resolve_location_name('DALLAS13')
+        self.assertEqual(location_name, location_name_expected)
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters', mask=object_mask)
+
+    def test_resolve_location_name_by_name(self):
+        location_name_expected = 'dal13'
+        object_mask = "mask[regions]"
+        location_name = self.ordering.resolve_location_name('dal13')
+        self.assertEqual(location_name, location_name_expected)
+        self.assert_called_with('SoftLayer_Location', 'getDatacenters', mask=object_mask)
+
+    def test_resolve_location_name_invalid(self):
+        exc = self.assertRaises(exceptions.SoftLayerError, self.ordering.resolve_location_name, None)
+        self.assertIn("Invalid location", str(exc))
+
+    def test_resolve_location_name_not_exist(self):
+        exc = self.assertRaises(exceptions.SoftLayerError, self.ordering.resolve_location_name, "UNKNOWN_LOCATION_TEST")
+        self.assertIn("does not exist", str(exc))
